const Gio = imports.gi.Gio;
const GLib = imports.gi.GLib;
const Extension = imports.misc.extensionUtils.getCurrentExtension();

function getSettings(schema)
{
    const GioSSS = Gio.SettingsSchemaSource;

    let schemaDir = Extension.dir.get_child('schemas');
    let schemaSource;
    if (schemaDir.query_exists(null))
        schemaSource = GioSSS.new_from_directory(schemaDir.get_path(), GioSSS.get_default(), false);
    else
        schemaSource = GioSSS.get_default();

    let schemaObj = schemaSource.lookup(schema, true);
    if (! schemaObj)
        throw new Error('Schema ' + schema + ' could not be found for extension ' + Extension.metadata.uuid + '. Please check your installation.');

    return new Gio.Settings({settings_schema: schemaObj})
}



function getItems(settings)
{
    let itemsString = settings.get_string('items');

    return itemsToArray(itemsString);
}

function setItems(settings, items)
{
    let itemsString = itemsToString(items);

    settings.set_string('items', itemsString);
}

function getEnableItems(settings)
{
    let items = getItems(settings);

    let itemsEnable = new Array();

    for (indexItem in items)
    {
        let item = items[indexItem];

        if (item["enable"])
	    itemsEnable.push(item);
    }

    return itemsEnable;
}

function getItem(settings, index)
{
    let items = getItems(settings);

    if (index >= 0 && index < items.length)
        return items[index];
    else
        return null;
}

function isEnable(settings, index)
{
    let item = getItem(settings, index);

    if (item != null)
        return item["enable"];
    else
        return null;
}

function changeEnable(settings, index, value)
{
    let items = getItems(settings);

    if (index < 0 && index >= items.length)
        return false;

    items[index]["enable"] = value;

    setItems(settings, items);

    return true;

}

function addItem(settings, label, cmd)
{
    let items = getItems(settings);

    let item = {
            "label" : label,
            "cmd" : cmd,
            "enable" : "1",
            "cmd-alt" : ""
        }
    
    items.push(item);

    setItems(settings, items);

    return true;
}

function delItem(settings, index)
{
    let items = getItems(settings);

    if (index < 1 && index >= items.length)
        return false;

    items.splice(index, 1);

    setItems(settings, items);

    return true;
}

function itemsToArray(itemsString)
{
    let items = itemsString.split("|");

    let itemsArray = new Array();

    for (let indexItem in items)
    {
        let itemDatas = items[indexItem].split(";");

        let item = {
                "label": itemDatas[0],
                "cmd" : itemDatas[1],
                "enable" : (itemDatas[2] == "1"),
                "cmd-alt" : (itemDatas.length > 3?itemDatas[3]:"")
            };

        itemsArray.push(item);
    }

    return itemsArray;
}

function itemsToString(itemsArray)
{	
    let items = new Array()

    for (indexItem in itemsArray)
    {
        let itemDatasArray = itemsArray[indexItem];
        
        let itemDatasString = itemDatasArray["label"] + ";" + itemDatasArray["cmd"] + ";" + (itemDatasArray["enable"]?"1":"0") + ";" + itemDatasArray["cmd-alt"];

        items.push(itemDatasString);
    }

    return items.join("|");
}
