const Gtk = imports.gi.Gtk;
const Lang = imports.lang;

const Extension = imports.misc.extensionUtils.getCurrentExtension();
const Lib = Extension.imports.lib;

const schema = "org.gnome.shell.extensions.SettingsCenter";

let vboxList;
let hboxsList = new Array();

function init()
{

}

function changeMenu(object, settings, text)
{
    settings.set_string('label-menu', text.get_text());
}

function changeReplace(object, pspec, settings)
{
    settings.set_boolean('replace-ss-menu', object.get_active());
}

function changeEnable(object, pspec, settings, index)
{
    Lib.changeEnable(settings, index, object.active);
}

function addCmd(object, settings, label, cmd)
{
    Lib.addItem(settings, label.get_text(), cmd.get_text());

    label.set_text("");
    cmd.set_text("");

    buildList(settings);
}

function delCmd(object, settings, index)
{
    Lib.delItem(settings, index);

    buildList(settings);
}

function buildList(settings)
{
    for (let indexHbox in hboxsList)
        hboxsList[indexHbox].destroy();

    hboxsList = new Array();

    let items = Lib.getItems(settings);

    for (let indexItem in items)
    {
        let item = items[indexItem];

        let hboxList = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
        let labelList = new Gtk.Label({label: item['label'], xalign: 0});
        let valueList = new Gtk.Switch({active: (item['enable'] == 1)});
        valueList.connect('notify::active', Lang.bind(valueList, changeEnable, settings, indexItem));
        let buttonDel = null;
        if (items.length > 1)
        {
            buttonDel = new Gtk.Button({ label: "Del" });
            buttonDel.connect("clicked", Lang.bind(buttonDel, delCmd, settings, indexItem));
        }

        hboxList.pack_start(labelList, true, true, 0);
        hboxList.add(valueList);
        if (buttonDel != null)
            hboxList.add(buttonDel);
        vboxList.add(hboxList);

        hboxsList.push(hboxList);
    }

    vboxList.show_all();
}

function buildPrefsWidget()
{
    let settings = Lib.getSettings(schema);

    let frame = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, border_width: 10 });

    let label = new Gtk.Label({ label: "<b>Global</b>", use_markup: true, xalign: 0 });
    let vbox = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, margin_left: 20 });



    let hboxMenu = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
    let labelMenu = new Gtk.Label({label: "Menu Label", xalign: 0});
    let valueMenu = new Gtk.Entry({ hexpand: true });
    valueMenu.set_text(settings.get_string('label-menu'));
    let buttonMenu = new Gtk.Button({ label: "Apply" });
    buttonMenu.connect("clicked", Lang.bind(buttonMenu, changeMenu, settings, valueMenu));

    hboxMenu.pack_start(labelMenu, true, true, 0);
    hboxMenu.add(valueMenu);
    hboxMenu.add(buttonMenu);
    vbox.add(hboxMenu);

    frame.add(label);
    frame.add(vbox);



    vbox = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, margin_left: 20 });

    let hboxReplace = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
    let labelReplace = new Gtk.Label({label: "Replace System Settings", xalign: 0});
    let valueReplace = new Gtk.Switch({active: settings.get_boolean("replace-ss-menu")});
    valueReplace.connect('notify::active', Lang.bind(valueReplace, changeReplace, settings));

    hboxReplace.pack_start(labelReplace, true, true, 0);
    hboxReplace.add(valueReplace);
    vbox.add(hboxReplace);

    frame.add(vbox);




    label = new Gtk.Label({ label: "<b>Menu Items</b>", use_markup: true, xalign: 0 });
    vboxList = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, margin_left: 20 });

    buildList(settings);

    frame.add(label);
    frame.add(vboxList);



    label = new Gtk.Label({ label: "<b>Add Menu</b>", use_markup: true, xalign: 0 });
    vbox = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, margin_left: 20 });

    let hboxLabelAdd = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
    let labelLabelAdd = new Gtk.Label({label: "Label", xalign: 0});
    let valueLabelAdd = new Gtk.Entry({ hexpand: true });

    hboxLabelAdd.pack_start(labelLabelAdd, true, true, 0);
    hboxLabelAdd.add(valueLabelAdd);
    vbox.add(hboxLabelAdd);

    let hboxCmdAdd = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
    let labelCmdAdd = new Gtk.Label({label: "Command", xalign: 0});
    let valueCmdAdd = new Gtk.Entry({ hexpand: true });

    hboxCmdAdd.pack_start(labelCmdAdd, true, true, 0);
    hboxCmdAdd.add(valueCmdAdd);
    vbox.add(hboxCmdAdd);

    let hboxButtonAdd = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL});
    let buttonAdd = new Gtk.Button({ label: "Add" });
    buttonAdd.connect("clicked", Lang.bind(buttonAdd, addCmd, settings, valueLabelAdd, valueCmdAdd));

    hboxButtonAdd.add(buttonAdd, true, true, 0);
    vbox.add(hboxButtonAdd);

    frame.add(label);
    frame.add(vbox);



    frame.show_all();

    return frame;
}
